library(ape)
library(geomorph)
library(MASS)

setwd("C:/Users/mqbpqrb4/Documents/!PhD Projects!/Fossil Archosaur Vertebrae/!Vertebrae Paper Submissions!/RSOS")

mydata <- read.table("RSOS Brocklehurst et al Landmarks.txt",header=TRUE,row.names=1,stringsAsFactors = FALSE)
coords <- as.matrix(mydata)
vertsdata <- arrayspecs(coords, 11, 2)

vertsdatalabel=read.csv("RSOS Brocklehurst et al Classifiers.csv")

# Perorm Procrustes alignment and do Principal Componenets Analysis  ----------------------
verts.gpa <- gpagen(vertsdata, print.progress = FALSE)
summary(verts.gpa)
plotAllSpecimens(verts.gpa$coords, mean = TRUE, links = NULL, label = TRUE, plot.param = list())


# PCA ---------------------------------------------------------------------

# Make basic morphospace plot in geomorph
#Do Principal Components Analysis
verts.pca<-plotTangentSpace(verts.gpa$coords,axis1 = 1, axis2 = 2,groups = vertsdatalabel$Group, legend = TRUE,warpgrids = TRUE)

# Procrustes Anova --------------------------------------------------------

#Perform the Procrustes Anova between different taxonomic groups
gdf <- geomorph.data.frame(verts.gpa,vertsdatalabel)
ProANOVA = advanced.procD.lm(coords ~ 1, ~ Group, groups = ~ Group, 
                             iter = 499, data = gdf, print.progress = FALSE)
summary(ProANOVA)

# Perform the second Procrustes Anova between vertebrae creating a furrowed or smooth
# thoracic ceiling.
# Subset data to contain only extant taxa
coords.M <- gdf$coords[ , ,gdf$Group %in% c("Aves","Crocodylia")]
Forked.M<- gdf$Forked.[gdf$Group %in% c("Aves","Crocodylia")]
gdf.M <- geomorph.data.frame(coords = coords.M, Forked. = Forked.M)

# Run second Procrustes Anova
ProANOVA.M = advanced.procD.lm(coords ~ 1, ~ Forked., groups = ~ Forked., 
                  iter = 499, data = gdf.M, print.progress = FALSE)
summary(ProANOVA.M)

# LDA ---------------------------------------------------------------------

# Doing the LDA using MASS
# Preparing the data
coords4cva = data.frame(two.d.array(verts.gpa$coords))
birdcrocdino =  cbind(coords4cva,vertsdatalabel)
#Subset into two datasets - the extan dataset and the xtinct dataset
birdcroc.coords = subset(birdcrocdino, Group == 'Aves' | Group == 'Crocodylia',1:22)
birdcroc.label = droplevels(unlist(c(subset(birdcrocdino, Group == 'Aves' | Group == 'Crocodylia',34))))
dino.coords = subset(birdcrocdino, Class == 'Dinosauria',1:22)

# Check LDA can correctly predict group membership of extant taxa
ld = lda(birdcroc.coords,birdcroc.label,CV=TRUE)
# Assess the accuracy of the prediction
# percent correct for each category of G
ct <- table(birdcroc.label, ld$class)
diag(prop.table(ct, 1))
# total percent correct
sum(diag(prop.table(ct)))

# Predicting fossil group membership based on extant sample
ld = lda(birdcroc.coords,birdcroc.label,CV=FALSE)
prop.lda = ld$svd^2/sum(ld$svd^2)
p.ld = predict(ld, dino.coords)
z = data.frame(p.ld$class)
z.prob = (p.ld$posterior)
rownames(z) = rownames(dino.coords)
# z is the data table containing the posterior probabilities of each vertebra being 
# classed as either bird_furrowed, croc_furrowed or croc_smooth

# Now run the same LDA on the extant data to generate ld scores for them
np.ld = predict(ld, birdcroc.coords)
# Make the dataframe of LD scores and grouping variables for both extinct and extant taxa
ld.data = cbind(rbind(np.ld$x,p.ld$x),vertsdatalabel)

# This dataframe can now be used to create the morphospaces and variation along the vertebral
# coulmn plots, as seen in the paper.
# For example, basic LDA morphospace plot
plot(x=ld.data$LD1,y=ld.data$LD2,col=ld.data$Group,pch=19)
legend(7,4.3,unique(ld.data$Group),col=1:length(ld.data$Group),pch=19)
